import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
const jwt = require('jsonwebtoken');
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err);
};
Vue.use(VueRouter);
const web = [
  {
    path: '/',
    redirect: '/adminCenter/homeIndex',
  },
  {
    path: '/login',
    name: 'login',
    meta: { title: '管理登录' },
    component: () => import('../views/login.vue'),
  },
  {
    path: '/adminCenter/homeIndex',
    name: 'adminCenter',
    component: () => import('@common/src/components/admin-frame/Home.vue'),
    children: [
      {
        path: '/adminCenter/homeIndex',
        name: 'admin_homeIndex',
        meta: { title: '首页' },
        component: () => import('../views/adminCenter/homeIndex/index.vue'),
      },
      // 管理账号管理
      {
        path: '/admin/admins',
        meta: { title: '管理员账号管理' },
        component: () => import('../views/admin/admins/index.vue'),
      },
      {
        path: '/admin/mechanism',
        meta: { title: '机构管理员账号管理' },
        component: () => import('../views/admin/mechanism/index.vue'),
      },
      {
        path: '/admin/business',
        meta: { title: '业务管理员账号管理' },
        component: () => import('../views/admin/business/index.vue'),
      },
      // 用户管理
      {
        path: '/user/personal',
        meta: { title: '个人用户' },
        component: () => import('../views/user/personal/index.vue'),
      },
      {
        path: '/user/company',
        meta: { title: '企业用户' },
        component: () => import('../views/user/company/index.vue'),
      },
      {
        path: '/user/expert',
        meta: { title: '专家用户' },
        component: () => import('../views/user/expert/index.vue'),
      },
      // 产品审核管理
      {
        path: '/product',
        meta: { title: '产品审核管理' },
        component: () => import('../views/product/index.vue'),
      },
      {
        path: '/product/data/info',
        meta: { title: '详细信息' },
        component: () => import('../views/product/data/info.vue'),
      },
      // e专利信息管理
      {
        path: '/patent/mess',
        meta: { title: '信息管理' },
        component: () => import('../views/patent/mess/index.vue'),
      },
      {
        path: '/patent/mess/detail',
        meta: { title: '信息编辑' },
        component: () => import('../views/patent/mess/detail.vue'),
      },
      {
        path: '/patent/trans',
        meta: { title: '专利交易' },
        component: () => import('../views/patent/trans/index.vue'),
      },
      {
        path: '/patent/trans/detail',
        meta: { title: '信息编辑' },
        component: () => import('../views/patent/trans/detail.vue'),
      },
      // 展会管理
      // 展会管理-科技成果
      {
        path: '/expo/achieve/live',
        meta: { title: '信息管理' },
        component: () => import('../views/expo/achieve/live/index.vue'),
      },
      {
        path: '/expo/achieve/trans',
        meta: { title: '交易审核管理' },
        component: () => import('../views/expo/achieve/trans/index.vue'),
      },
      // 展会管理-培训问诊
      {
        path: '/expo/train/live',
        meta: { title: '信息管理' },
        component: () => import('../views/expo/train/live/index.vue'),
      },
      // 展会管理-科技频道
      {
        path: '/expo/channel/live',
        meta: { title: '信息管理' },
        component: () => import('../views/expo/channel/live/index.vue'),
      },
      // 新闻信息管理
      {
        path: '/news/column',
        meta: { title: '栏目管理' },
        component: () => import('../views/news/column/index.vue'),
      },
      {
        path: '/news/mess',
        meta: { title: '信息管理' },
        component: () => import('../views/news/mess/index.vue'),
      },
      {
        path: '/news/mess/detail',
        meta: { title: '信息管理' },
        component: () => import('../views/news/mess/detail.vue'),
      },

      {
        path: '/subscribe/mess',
        meta: { title: '信息管理' },
        component: () => import('../views/subscribe/mess/index.vue'),
      },
      // 预约服务管理
      // 系统设置
      {
        path: '/system/power',
        meta: { title: '角色设置' },
        component: () => import('../views/system/power/index.vue'),
      },
      {
        path: '/system/dictionary',
        meta: { title: '字典表设置' },
        component: () => import('../views/system/dictionary/index.vue'),
      },
      {
        path: '/system/dictionary/detail',
        meta: { title: '字典表设置-字典项' },
        component: () => import('../views/system/dictionary/detail.vue'),
      },
      {
        path: '/system/uppasswd',
        meta: { title: '修改密码' },
        component: () => import('../views/system/uppasswd/index.vue'),
      },
    ],
  },
];
const routes = [...web];
const router = new VueRouter({
  mode: 'history',
  base: process.env.VUE_APP_ROUTER,
  routes,
});
router.beforeEach((to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = sessionStorage.getItem('token');
  if (to.path == '/adminCenter/homeIndex') {
    if (!token) {
      next('/login');
    } else {
      let user = jwt.decode(token);
      store.commit('setUser', user, { root: true });
      next();
    }
  } else {
    let user = jwt.decode(token);
    store.commit('setUser', user, { root: true });
    next();
  }
});

export default router;
